#
# spec file for package ddcutil
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           ddcutil
Version:        0.8.5
Release:        6.1
Summary:        Query and update monitor settings
License:        GPL-2.0+
Group:          System/GUI/Other
Url:            http://github.com/rockowitz/ddctool
Source:         https://github.com/rockowitz/%{name}/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gcc
BuildRequires:  i2c-tools
BuildRequires:  libtool
BuildRequires:  python-devel
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(libdrm)
BuildRequires:  pkgconfig(libudev)
BuildRequires:  pkgconfig(libusb-1.0)
BuildRequires:  pkgconfig(xrandr)
BuildRequires:  pkgconfig(zlib)

%description
ddcutil communicates with monitors implementing MCCS (Monitor Control Command
Set), using either the DDC/CI protocol on the I2C bus or as a Human Interface
Device on USB.

A particular use case for ddcutil is as part of color profile management.
Monitor calibration is relative to the monitor color settings currently in
effect, e.g. red gain.  ddcutil allows color related settings to be saved at
the time a monitor is calibrated, and then restored when the calibration is
applied.

%package -n libddcutil0
Summary:        Shared library to query and update monitor settings
Group:          System/Libraries

%description -n libddcutil0
Shared library version of ddcutil, exposing a C API.

ddcutil communicates with monitors implementing MCCS (Monitor Control Command
Set), using either the DDC/CI protocol on the I2C bus or as a Human Interface
Device on USB.

%package -n libddcutil-devel
Summary:        Development files for libddcutil
Group:          Development/Libraries/C and C++
Requires:       libddcutil0 = %{version}

%description -n libddcutil-devel
Header files and pkgconfig control file for libddcutil.

%prep
%setup -q

%build
./autogen.sh
%configure --enable-lib=yes --enable-drm=yes --enable-usb=yes \
   --docdir="%{_datadir}/doc/packages/%{name}"
make %{?_smp_mflags} V=1

%check
make %{?_smp_mflags} check

%install
%make_install
rm %{buildroot}%{_datadir}/doc/libddcutil/AUTHORS
rmdir %{buildroot}%{_datadir}/doc/libddcutil

%post   -n libddcutil0 -p /sbin/ldconfig
%postun -n libddcutil0 -p /sbin/ldconfig

%files
%doc AUTHORS COPYING NEWS.md README.md ChangeLog
%dir %{_datadir}/%{name}
%dir %{_datadir}/%{name}/data
%{_datadir}/%{name}/data/*rules
%{_datadir}/%{name}/data/90-nvidia-i2c.conf
%{_mandir}/man1/ddcutil.1*
%{_bindir}/ddcutil

%files -n libddcutil0
%doc AUTHORS COPYING NEWS.md README.md ChangeLog
%{_libdir}/libddcutil.so.*

%files -n libddcutil-devel
%{_includedir}/ddcutil_types.h
%{_includedir}/ddcutil_c_api.h
%{_libdir}/pkgconfig/ddcutil.pc
%{_libdir}/libddcutil.so
%dir %{_datadir}/%{name}
%dir %{_datadir}/%{name}/data/
%{_datadir}/%{name}/data/FindDDCUtil.cmake

%changelog
* Wed Dec 13 2017 alarrosa@suse.com
- Update to ddcutil 0.8.5
  * This release contains a large number of minor enhancements and bug fixes
  * The environment command is extensively revised. The increasingly large
    collection of tests has been consolidated.
  * The required glib-2.0 version has been increased from 2.16 to 2.32
    reflecting the use of glib thread functions.
  * Fix a logic error in the VCP version comparison function vcp_version_le().
    This bug affected only audio related VCP feature codes x8f, x91, and x93.
    It also affected experimental command watch which listens for monitor
    changes not made by ddcutil, i.e. by pressing buttons on the monitor.
  * Properly handle the failure case where a display is detected on an I2C bus
    (EDID is read) but DDC communication fails, and the user specifies the
    display on the command line using the I2C bus number (option --bus).
  * Fix the cause of a segfault when the loadvcp command reads a user modified
    VCP file. The command now fails gracefully if none of MFG_ID, MODEL,
    and SN are present.
  * Fix the cause of a segfault when displaying I2C functionality flags in the
  - -environment command. This segfault was seen only in 32 bit versions of
    ddcutil.
  * The --stats option showed incorrect time statistics on 32 bit versions of
    ddcutil.
  * Add "-lddcutil" to output of "pkgconfig ddcutil --libs".
  * Improve reporting of the individual errors that result in command failure
    due to maximum I2C retries exceeded.
  * interrogate, environment and usbenvironment now redirect all stderr output
    to stdout for easier capture
  * Added command line options -trcfile and -trcfunc to enable tracing by
    file name and function name.
  * Added configuration option --enable-x11 controlling whether X11 related
    diagnostics are included in the environment and interrogate commands,
    allowing ddcutil to build in embedded environments that lack X11.
    The default is yes.
  * Verbose EDID decription, e.g. on command detect --verbose, now reports EDID
    byte 24 (x14), the supported features bitmap. This is purely informational.
  * Ongoing work to make functions thread safe.
  * Code cleanup.
  * The full list of changes can be read at
    http://www.ddcutil.com/release_notes/
* Tue Sep  5 2017 jengelh@inai.de
- Clear repeated summary, fix RPM groups, repair description not
  matching the filelists.
* Tue Sep  5 2017 alarrosa@suse.com
- Use the sources as distributed in github, which is different from
  the sources in rockowitz's OBS project
- Use automake/autoconf/libtool
* Mon Sep  4 2017 alarrosa@suse.com
- Don't unset the _unpackaged_files_terminate_build test,
  which was forgotten from the original spec file. Instead,
  set --docdir correctly for configure and remove an unwanted
  file after make install.
- Add the %%doc line to the library package so it also installs the license
* Fri Sep  1 2017 alarrosa@suse.com
- Initial release of ddcutil 0.8.4 based on rockowitz's generic spec file
